@@ -3,6 +3,9 @@
 #![warn(clippy::pedantic)]
 #![warn(missing_docs)]
 #![doc = include_str!("../README.md")]
+#![no_std]
+
+extern crate alloc;
 
 mod iface;
 mod phy;
