@@ -1,5 +1,5 @@
 mod eth;
-mod slip;
+pub mod slip;
 
 pub use eth::Eth;
 pub use slip::Slip;
